Module completion

Module completion 

Completion of tree paths and action arguments.

Completion is done functionally, see examples on github for how to implement.

Structs

ActionMatch
Match string and qualified name of action.
Completion
Represents a single possible completion
CompletionInfo
Completion item.
Interface
The main interface to input reading and other terminal operations
Prompter
Provides access to the current state of input while a read_line call is in progress.

Enums

ReadResult
Returned from read_line to indicate user input

Traits

Completer
Performs completion for Prompter when triggered by a user input sequence
Terminal
Defines a low-level interface to the terminal

Functions

create_action_completion_items
Constructs a set of space delimited actions that could be completed at the current path.
create_tree_completion_items
Constructs a set of space delimited items that could be completed at the current path.
tree_completions
Determines from a set of items the ones that could be completed from the given line.
word_break_start
Returns the start position of the last word, delimited by any character.