Completion of tree paths and action arguments.
Completion is done functionally, see examples on github for how to implement.
Structs
- Action
Match - Match string and qualified name of action.
- Completion
- Represents a single possible completion
- Completion
Info - Completion item.
- Interface
- The main interface to input reading and other terminal operations
- Prompter
- Provides access to the current state of input while a
read_linecall is in progress.
Enums
- Read
Result - Returned from
read_lineto indicate user input
Traits
- Completer
- Performs completion for
Prompterwhen triggered by a user input sequence - Terminal
- Defines a low-level interface to the terminal
Functions
- create_
action_ completion_ items - Constructs a set of space delimited actions that could be completed at the current path.
- create_
tree_ completion_ items - Constructs a set of space delimited items that could be completed at the current path.
- tree_
completions - Determines from a set of items the ones that could be completed from the given line.
- word_
break_ start - Returns the start position of the last word, delimited by any character.